Tvstats
*******
Scrape data of all the episodes of a Tv Series from IMDB.

Installation
============
Run
::

    python setup.py install

Dependencies
============
tvstats is based on Python 2.7. Requires ``BeautifulSoup4`` for parsing, ``requests`` for downloading html.
``Matplotlib`` is required(optional) for using graph module.

Usage
=====
Run the simple command
::

    tvstats url

to generate json data.
URL should point to homepage of a tv series. eg. http://www.imdb.com/title/tt0108778/?ref_=fn_al_tt_1

For options and help run
::

    tvstats -h

Why?
====
Here are my reasons:

* I was bored and had time to kill.
* I love watching Tv Series. Thought it would be good to analyse some data
  before starting a new one.
* Graphs are fun.
* Lastly, I wanted to test out ``BeautifulSoup4`` :).

Issues, Bugs, Graphs?
=====================
.. |issues| replace:: https://github.com/leosartaj/tvstats/issues

Let me knwow about the issues at |issues|. Feel free to add new graphs or improve.

Examples
========
.. _here: https://github.com/leosartaj/tvstats/tree/master/data/jsonData
.. _Graphs: https://github.com/leosartaj/tvstats/tree/master/data/graphs

All the datasets can be found here_. Graphs_ were made using ``graph`` function in 'graph.py'.

Friends
-------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/friends.png

Game Of Thrones
---------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/gameOfThrones.png

Breaking Bad
-------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/breakingBad.png

The Big Bang Theory
-------------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/tbbt.png

How I Met Your Mother
---------------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/himym.png

Prison Break
------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/prisonBreak.png

Hannibal
---------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/hannibal.png

Suits
------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/suits.png

Dexter
------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/dexter.png

Arrow
------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/arrow.png

Person Of Interest
------------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/personOfInterest.png

Homeland
---------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/homeland.png

House Of Cards
--------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/houseOfCards.png

How to Get Away With Murder
----------------------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/howToGetAwayWithMurder.png

Orange Is The New Black
-----------------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/orangeIsTheNewBlack.png

Shameless
---------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/shameless.png

Sons Of Anarchy
----------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/sonsOfAnarchy.png

Spartacus
---------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/spartacus.png

The Walking Dead
-----------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/theWalkingDead.png

Vikings
-------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/vikings.png

Flash
------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/flash.png

The Wire
--------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/theWire.png

Continuum
---------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/continuum.png

Lost
----

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/lost.png

The Sopranos
------------

.. image:: https://raw.githubusercontent.com/leosartaj/tvstats/master/data/graphs/theSopranos.png
